summaryrefslogtreecommitdiffstats
path: root/src/gui/application/RosegardenGUIView.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/application/RosegardenGUIView.h')
-rw-r--r--src/gui/application/RosegardenGUIView.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/gui/application/RosegardenGUIView.h b/src/gui/application/RosegardenGUIView.h
index 44bf12b..da52c9f 100644
--- a/src/gui/application/RosegardenGUIView.h
+++ b/src/gui/application/RosegardenGUIView.h
@@ -87,7 +87,7 @@ public:
SegmentParameterBox*,
InstrumentParameterBox*,
TrackParameterBox*,
- TQWidget *tqparent = 0,
+ TQWidget *parent = 0,
const char *name=0);
/**
@@ -98,7 +98,7 @@ public:
/**
* returns a pointer to the document connected to the view
* instance. Mind that this method requires a RosegardenGUIApp
* instance as a tqparent widget to get to the window document
* pointer by calling the RosegardenGUIApp::getDocument() method.
*
* @see RosegardenGUIApp#getDocument
@@ -98,7 +98,7 @@ public:
* returns a pointer to the document connected to the view
* instance. Mind that this method requires a RosegardenGUIApp
- * instance as a tqparent widget to get to the window document
+ * instance as a parent widget to get to the window document
* pointer by calling the RosegardenGUIApp::getDocument() method.
*